function Mandelbrot(rez,iter,X,Y)
% iter - broj iteracija 
% rez  - "rezolucija", tj. broj tacaka unutar slike (kvadriran)
% X -  vektor duzine 2, x koordinate, grafik se crta od X(1) do X(2)
% Y -  vektor duzine 2, y koordinate, grafik se crta od Y(1) do Y(2)
% test:
% Mandelbrot(400,100,[-1.5,0.5],[-1,1])

% z(n+1) = z(n)^2 + c
% za fiksirano z=0, menjamo c

z=0;
[cRe,cIm]=meshgrid(linspace(X(1),X(2),rez),linspace(Y(1),Y(2),rez));
c=cRe+1i*cIm;
for i = 1:rez
    for j=1:rez
        M(i,j)=Mandelbrot_pom(z,c(i,j),iter);
    end
end

imagesc(M); % crta sliku 


function  iz=Mandelbrot_pom(z,c,iter)

R=2; %slucaj kad divergira
iz=iter;
for i=1:iter
    if abs(z) > R
        iz = i;
        return;
    end   
    z=z^2+c;
end
